@@ -7,6 +7,7 @@ import forge
 from pydantic import create_model, constr
 from django.db import models
 from fastapi import APIRouter, Security, Path, Body, Depends, Query, Response
+from starlette.status import HTTP_204_NO_CONTENT
 from ..schemas import Access, Error
 from ..utils.fastapi import Pagination, depends_pagination
 from ..utils.pydantic_django import transfer_to_orm, TransferAction
@@ -189,7 +190,7 @@ class DjangoRouterSchema(RouterSchema):
         self.__router.add_api_route(self.id_field_placeholder, methods=['PUT'], endpoint=self._create_endpoint_put(), response_model=self.get_referenced)
 
     def _create_route_delete(self):
-        self.__router.add_api_route(self.id_field_placeholder, methods=['DELETE'], endpoint=self._create_endpoint_delete(), status_code=204)
+        self.__router.add_api_route(self.id_field_placeholder, methods=['DELETE'], endpoint=self._create_endpoint_delete(), status_code=HTTP_204_NO_CONTENT)
 
     def get_queryset(self, parent_ids: Optional[List[str]] = None, access: Optional[Access] = None, is_annotated: bool = False):
         if self.parent:
@@ -199,7 +200,8 @@ class DjangoRouterSchema(RouterSchema):
         if is_annotated:
             queryset = queryset.annotate(*[models.Count(field.name) for field in self.model._meta.get_fields() if isinstance(field, (models.ManyToManyRel, models.ManyToOneRel))])
 
-        return queryset
+        # cockroachdb returns multiple rows when searching on related fields, therefore perform a distinct on the primary key
+        return queryset.distinct('pk')
 
     def objects_filter(self, access: Optional[Access] = None) -> models.Q:
         if hasattr(self.model, 'tenant_id'):
@@ -315,7 +317,11 @@ class DjangoRouterSchema(RouterSchema):
         ])
 
     def search_filter(self, **kwargs) -> models.Q:
-        return models.Q(**remove_none(kwargs))
+        q = models.Q(**remove_none(kwargs))
+        if self.delete_status and 'status__in' in kwargs and kwargs['status__in'] is None:
+            q &= ~models.Q(status=self.delete_status)
+
+        return q
 
     def search_filter_fields(self):
         fields = defaultdict(list)
@@ -340,7 +346,7 @@ class DjangoRouterSchema(RouterSchema):
                     continue
 
             if field.null:
-                fields[field].append(forge.kwarg(f'{field_name}__isnull', type=Optional[bool], default=Query(**{**query_options, 'alias': None})))
+                fields[field].append(forge.kwarg(f'{query_options.get("alias") or field_name}__isnull', type=Optional[bool], default=Query(**{**query_options, 'alias': None})))
 
             if isinstance(field, (models.ManyToManyRel, models.ManyToOneRel)):
                 field_name += '__count'
@@ -381,7 +387,10 @@ class DjangoRouterSchema(RouterSchema):
 
             elif isinstance(field, models.CharField):
                 if field.choices:
-                    query_options.update(alias=field_name)
+                    query_options['alias'] = field_name
+                    if field_name == 'status' and self.delete_status:
+                        query_options['description'] = f"When not set, objects with status {self.delete_status} are excluded"
+
                     field_name += '__in'
                     field_type = List[field_type]
 
@@ -530,7 +539,7 @@ class DjangoRouterSchema(RouterSchema):
         obj = self._object_get(kwargs, access=access)
         self.object_delete(access=access, instance=obj)
 
-        return ''
+        return Response(status_code=HTTP_204_NO_CONTENT)
 
     def _create_endpoint_delete(self):
         return self._add_endpoint_description(Method.DELETE, forge.sign(*[
